Changelog
=========

`0.1.1`_ (2018-03-11)
---------------------

- fix various styling issues
- add --configuration-directory command line argument
- fix incompatibilies with peewee 3


`0.1`_ (2017-11-13)
---------------------

- first release

.. _0.1: https://github.com/Muges/erika/releases/tag/v0.1
.. _0.1.1: https://github.com/Muges/erika/compare/v0.1...v0.1.1